@@ -1,7 +1,9 @@
 # to avoid variability on terminals with different capabilities
 # plus generally random options being set
 
-if(suppressWarnings(require('unitizer'))) {
+if(getRversion() < "3.2.0") {
+  warning("Cannot run tests with R version less than 3.2.0.")
+} else if(suppressWarnings(require('unitizer'))) {
   old.opt <- options(
     fansi.tabs.as.spaces=FALSE,
     fansi.tab.stops=8L,
